package com.example.prm02

import android.app.Activity
import android.app.AlertDialog
import android.content.ContentValues
import android.content.Intent
import android.net.Uri
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.widget.Toast
import kotlinx.android.synthetic.main.activity_add_debtor.*

class UpdateDebtorActivity : AppCompatActivity() {
    private lateinit var dbHelper: DbHelper
    var debtorId: Int? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_add_debtor)

        dbHelper = DbHelper(this)

        val bundle:Bundle? = intent.extras

        bundle?.let {
            debtorId = bundle.getInt(DbContract.DebtorEntry.COLUMN_ID)

            val debtor = DataManager.fetchDebtor(dbHelper, debtorId!!)

            debtor?.let {
                etName.setText(debtor.name)
                etDebt.setText(debtor.debt)
            }
        }

        bSave.setOnClickListener {
            saveDebtor()
        }

        bCancel.setOnClickListener {
            finish()
        }

        bDelete.setOnClickListener{
            val builder = AlertDialog.Builder(this)
            builder.setMessage("Do you want to delete debt ?")
                .setPositiveButton("yes") { dialog, eId ->
                    val result = DataManager.deleteDebtor(dbHelper, debtorId!!)
                    Toast.makeText(
                        applicationContext, "$result record deleted",
                        Toast.LENGTH_SHORT
                    ).show()

                    setResult(Activity.RESULT_OK, Intent())
                    finish()
                }
                .setNegativeButton("No") { dialog, id ->
                    dialog.dismiss()
                }

            val dialog = builder.create()
            dialog.setTitle("Are you sure")
            dialog.show()
        }

        bSendSms.setOnClickListener{
            val uri = Uri.parse("content://com.example.prm02/debtor/$debtorId")

            contentResolver.query(uri, null, null, null, null)?.use {
                var content = StringBuffer()
                val nameCol = it.getColumnIndexOrThrow("name")
                val debtCol = it.getColumnIndexOrThrow("debt")
                if (it.moveToFirst()) {
                    do {
                        content.append(it.getString(nameCol)).append(" ")
                        content.append(it.getString(debtCol)).append(" ")
                    } while(it.moveToNext())
                }

                val intent = Intent(Intent.ACTION_SEND).apply {
                    putExtra(Intent.EXTRA_TEXT, content.toString())
                    type = "text/plain"
                }

                startActivity(Intent.createChooser(intent, "Share data in: "))
            }
        }

        bSimulate.setOnClickListener{
            Log.i("#############   test  #################", "#############   test000  #################")
            val simulateDebtor = Intent(this, SimulateDebtorActivity::class.java)
            simulateDebtor.putExtra(DbContract.DebtorEntry.COLUMN_ID, debtorId )
            startActivityForResult(simulateDebtor, 3)
        }

    }

    private fun saveDebtor() {

        var isValid = true

        etName.error = if (etName?.text.toString().isEmpty()) {
            isValid = false
            "Required Field"
        } else null

        etDebt.error = if (etDebt?.text.toString().isEmpty()) {
            isValid = false
            "Required Field"
        } else null


        val pattern = "[0-9]+((\\.[0-9]+)|())".toRegex()

        etDebt.error = if (!pattern.matches(etDebt?.text.toString()) ) {
            isValid = false
            "Not valid value"
        } else null


        if (isValid) {
            val name = etName?.text.toString()
            val debt = etDebt?.text.toString()

            val updatedDebtor = Debtor(debtorId!!, name, debt)
            DataManager.updateDebtor(dbHelper, updatedDebtor)
            setResult(Activity.RESULT_OK, Intent() )

            Toast.makeText(applicationContext, "Debtor updated", Toast.LENGTH_SHORT).show()

            finish()
        }


        finish()
    }


}
